package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.30.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.30.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````HA4``#0```#DD````````#0`(``*
M`"@`%P`6``8````T````-````#0```!``0``0`$```0````$`````P```'0!
M``!T`0``=`$``!<````7````!`````$````!````````````````````;`\`
M`&P/```$`````!````$`````$````!`````0```I*@``*2H```4`````$```
M`0````!`````0````$```+1*``"T2@``!``````0```!````](T``/2=``#T
MG0``,`(``(`2```&`````!````(````$C@``!)X```2>``#0````T`````8`
M```$````4.5T9%!]``!0?0``4'T``/0```#T````!`````0```!1Y71D````
M```````````````````````&````$````%+E=&3TC0``])T``/2=```,`@``
M#`(```0````!````+VQI8B]L9"UM=7-L+6DS.#8N<V\N,0``$0```$D````(
M````"``````0$``E0`2`*``0!*"&`(2``0``"R`$"3B`$D&*!`@(`````$D`
M``!-````40```%(```!8````60```%H`````````7````%T`````````7@``
M`%\```!A``````````````!J?YI\ZM/O#L[>1RUOQ=\?+L6;MKB-\0[49-1\
M(?_D#MEQ6!SZH6Q@PN4_++(!BV]"^M>'XD?&`;OCDGQ5PSS29Z_,9H@'<--#
M1=7L,V+;[16,)<Q_J9R;X*<""FL:GE"CX/M)``````````````````````P`
M`````````````!(```"N`0`````````````2````%```````````````$0``
M`-0!`````````````!$```!0`0`````````````2````&P``````````````
M$@```(T!`````````````!(````C```````````````2````*@``````````
M````$@```.$!`````````````!(```"9`0`````````````2````(`,`````
M````````(0```#,``````````````!(````Y```````````````2````0```
M````````````$@```.T"`````````````!(```#>`@`````````````2````
M9@(`````````````$@````<"`````````````!(```!'```````````````2
M````FP(`````````````$@```$X``````````````!(```!6````````````
M```2````A`(`````````````$@```%X``````````````!(```!D````````
M```````2````;0``````````````(````-<"`````````````!(```")````
M```````````2````C@``````````````$@```/(!`````````````!$```"B
M`@`````````````2````-`(`````````````$@```)4``````````````!(`
M``"<```````````````@````)@(`````````````$@```%4#````````````
M`!(```"M`@`````````````1````'P,`````````````$0```%@"````````
M`````!(````,`P`````````````2````(0,`````````````$0```+H`````
M`````````!(````$`P`````````````2````7@$`````````````$@```,,`
M`````````````"(```#2```````````````2````SP(`````````````$@``
M`$0"`````````````!(```#7```````````````2````W0``````````````
M(````(\"`````````````!(```#W```````````````2````?@$`````````
M````$@```/P``````````````"`````8`0`````````````2````=`(`````
M````````$@```&T!`````````````!(````>`0`````````````2````+P$`
M````````````$@````("`````````````!(```!?```````````````2````
M$P(`````````````$@```$T"`````````````!(```#]`@`````````````2
M````-0$`````````````$@```/4"`````````````!(```#]`0``````````
M```2````O`$`````````````$@```"D#`````````````!(````>`P``````
M```````A````20$`````````````$@```!D#``#($P``V@$``!(`"@#.`0``
M'3H```$````2``L`EP,``&@B``##!0``$@`*`$,$```G*P``7@```!(`"@!T
M`P``8QT```4````2``H``00````0```!````$@`'`+H#```K*```_`(``!(`
M"@`G!```:!T``+T!```2``H`\@,``"2@````````$``4`(4#``"Y(0``KP``
M`!(`"@"D`P``^!L``#L````2``H`K`,``$0A``!*````$@`*`-`#``"W-P``
M_P```!(`"@#E`P``)1\``!4````2``H`/@0``'2P````````$``4`#H#``"]
M%0``-P```!(`"@`'!```.A\``*X````2``H`VP,``""@```$````$0`3`"`$
M```DH````````!``$P#W`P``HA4````````0``H`_@,``&4W``!2````$@`*
M`$,#``".(0``*P```!(`"@!>`P``B!P``-L````2``H`-`0``+8X```G`0``
M$@`*`!,$``#H'P``7`$``!(`"@``;&EB<&5R;"YS;P!O<&5N9&ER`'-T9&5R
M<@!R96%L;&]C`&%C8V5S<P!S;G!R:6YT9@!L<V5E:P!G971P:60`<W1R8VUP
M`'5N;&EN:P!M96UM;W9E`'-T<FYC;7``;'-T870`8VQO<V5D:7(`7TE435]D
M97)E9VES=&5R5$U#;&]N951A8FQE`&]P96X`<W1R<W1R`'-T<F-H<@!?7V1E
M<F5G:7-T97)?9G)A;65?:6YF;U]B87-E<P!R96%D;&EN:P!?7V-X85]F:6YA
M;&EZ90!E>&ET`&-L;W-E`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`<F5A
M9`!?7W)E9VES=&5R7V9R86UE7VEN9F]?8F%S97,`<FUD:7(`7U]E<G)N;U]L
M;V-A=&EO;@!M:V1I<@!P=&AR96%D7V=E='-P96-I9FEC`&=E='5I9`!097)L
M7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7VQO8VL`<&5R
M;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`
M4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!?9FEN:0!03%]D;U]U
M;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E90!0
M97)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!0
M97)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R
M=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`
M4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``
M;&EB8RYM=7-L+7@X-BYS;RXQ`&9P<FEN=&8`<W1R9'5P`'!T:')E861?871F
M;W)K`')E861D:7(`<W!R:6YT9@!S=')T;VL`<W1R;F-P>0!?7VQI8F-?<W1A
M<G1?;6%I;@!?7U]E;G9I<F]N`%]?<W1A8VM?8VAK7V9A:6P`7W-T87)T7V,`
M9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-U<G)E;G1?97AE8U]P
M<F]C`'!A<E]C=7)R96YT7V5X96,`<&%R7W-E='5P7VQI8G!A=&@`<&%R7VUK
M=&UP9&ER`'AS7VEN:70`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%2
M7T)/3U0`<VAA7W5P9&%T90!M>5]P87)?<&P`<&%R7V)A<V5N86UE`%]?8G-S
M7W-T87)T`'-H85]I;FET`'!A<E]D:7)N86UE`'!A<E]I;FET7V5N=@!?961A
M=&$`<&%R7V9I;F1P<F]G`'-H85]F:6YA;`!?96YD`'!A<E]C;&5A;G5P`"]U
M<W(O;&EB+W!E<FPU+V-O<F5?<&5R;"]#3U)%`````,"?```(````S)\```@`
M``#4GP``"`````"@```(````!*````@````(H```"`````R@```(````$*``
M``@````4H```"````""@```(````Q)\```8#``#(GP``!@0``-"?```&&P``
MV)\```8?``#<GP``!B,``."?```&)@``Y)\```8J``#HGP``!BX``.R?```&
M,P``\)\```8W``#TGP``!CD``/B?```&.@``_)\```8_``#@G@``!P$``.2>
M```'`@``Z)X```<%``#LG@``!P8``/">```'!P``])X```<(``#XG@``!PD`
M`/R>```'"@```)\```<+```$GP``!PT```B?```'#@``#)\```</```0GP``
M!Q```!2?```'$0``&)\```<2```<GP``!Q,``""?```'%```))\```<5```H
MGP``!Q8``"R?```'%P``,)\```<8```TGP``!QD``#B?```'&@``/)\```<<
M``!`GP``!QT``$2?```''@``2)\```<@``!,GP``!R$``%"?```'(@``5)\`
M``<D``!8GP``!R4``%R?```'*```8)\```<I``!DGP``!RL``&B?```'+```
M;)\```<M``!PGP``!R\``'2?```',```>)\```<Q``!\GP``!S(``("?```'
M-```A)\```<U``"(GP``!S8``(R?```'.```D)\```<[``"4GP``!SP``)B?
M```'/0``G)\```<^``"@GP``!T```*2?```'00``J)\```="``"LGP``!T,`
M`+"?```'1```M)\```=%``"XGP``!T8``+R?```'2```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(/L#.CX!@``Z.DI``"#Q`S#````````````````````_[,$````_Z,(````
M`````/^C#````&@`````Z>#_____HQ````!H"````.G0_____Z,4````:!``
M``#IP/____^C&````&@8````Z;#_____HQP```!H(````.F@_____Z,@````
M:"@```#ID/____^C)````&@P````Z8#_____HR@```!H.````.EP_____Z,L
M````:$````#I8/____^C,````&A(````Z5#_____HS0```!H4````.E`____
M_Z,X````:%@```#I,/____^C/````&A@````Z2#_____HT````!H:````.D0
M_____Z-$````:'````#I`/____^C2````&AX````Z?#^____HTP```!H@```
M`.G@_O___Z-0````:(@```#IT/[___^C5````&B0````Z<#^____HU@```!H
MF````.FP_O___Z-<````:*````#IH/[___^C8````&BH````Z9#^____HV0`
M``!HL````.F`_O___Z-H````:+@```#I</[___^C;````&C`````Z6#^____
MHW````!HR````.E0_O___Z-T````:-````#I0/[___^C>````&C8````Z3#^
M____HWP```!HX````.D@_O___Z.`````:.@```#I$/[___^CA````&CP````
MZ0#^____HX@```!H^````.GP_?___Z.,````:``!``#IX/W___^CD````&@(
M`0``Z=#]____HY0```!H$`$``.G`_?___Z.8````:!@!``#IL/W___^CG```
M`&@@`0``Z:#]____HZ````!H*`$``.F0_?___Z.D````:#`!``#I@/W___^C
MJ````&@X`0``Z7#]____HZP```!H0`$``.E@_?___Z.P````:$@!``#I4/W_
M__^CM````&A0`0``Z4#]____H[@```!H6`$``.DP_?___Z.\````:&`!``#I
M(/W___^CP````&AH`0``Z1#]____H\0```!H<`$``.D`_?___Z/(````:'@!
M``#I\/S___^CS````&B``0``Z>#\____H]````!HB`$``.G0_/___Z/4````
M:)`!``#IP/S___^CV````&B8`0``Z;#\____H]P```!HH`$``.F@_/___Z/@
M````:*@!``#ID/S___^CY````&BP`0``Z8#\____H^@```!HN`$``.EP_/__
M_Z,(`0``9I#_HQ0!``!FD/^C'`$``&:0C4PD!(/D\/]Q_(U!"%6)Y5=6B<Y3
MZ!("``"!P_**``!1@^P,4(U!!%!1Z&G^__^+@R@!``"#Q`Q04/^S)`$``.CS
M_/__BX/T````@\00B[L$`0``@#@`=33HJOW__XF#G!$``(7`=0J#[`QJ`>@V
M_O__@^P,4.B-_O__6?\WZ`7___^#Q!#&@#T&````@^P,_S?H\?[__X"(G@(`
M``):_S?HXO[__X/$$("(G@(```&+!H/`!3W___\_=A104(V#G:'___^S#`$`
M`%#H&/S__X/L#,'@`E#H#/[__XM^!(/$$+D!````B8.0$0``QX.4$0``!```
M`(L7B1"-D]^C__^)4`2+DTP!``")4`B-D^*C__^)4`R+%CG*?@J+-(^)=(@,
M0>OR@^P,QT20#`````"#P@-J`%"-@U]]__]24/^SG!$``.A>_/__@\0@B<:%
MP'43@^P,_[.<$0``Z&?]__^#Q!")QH/L#/^SG!$``.CD_/__C8/KH?__Z)0"
M``"#Q!"%P'4P@[N8$0```'41C8.@H?__Z'D"``")@Y@1``"+@Y@1``"%P'0,
M@^P,4.BL%0``@\00@^P,_[.<$0``Z.3]___HO_K__X/$$(UE\(GP65M>7UV-
M8?S#,>V)X(/D\%!0Z`````"!!"14B```4.@`````4^@Q````@<,1B0``@^P0
MBT0D&&H`C5`$_[/X````_[,``0``4O\P_[/L````Z$'\__^#Q"A;PXL<),/H
M2@$```77B```C8A0`0``C9!0`0``.<IT&(N`_````(7`=`Y5B>6#[!11_]"#
MQ!#)P\/H&P$``('!I(@``%6)Y5:^`@```%.-F5`!``"-@5`!```IV,'X`IGW
M_H7`=!.+D1@!``"%TG0)45%04__2@\00C67X6UY=PU6)Y5=64^AW____@<-7
MB```@^P,@+ML`0```'5I@[L4`0```'01@^P,_[,L`0``Z!+]__^#Q!"-LRC_
M__^-NRS___\I]\'_`D^+@W`!```Y^',,0(F#<`$``/\4ANOJZ"+___^#NP@!
M````=!*#[`R-@\#?__]0Z,+\__^#Q!#&@VP!```!C67T6UY?7<-5Z`````!:
M@<+.AP``B>53Z-_^__^!P[^'``!0@[L<`0```'09C8-T`0``4FH`4(V#P-__
M_U#HA?S__X/$$(M=_,GIY/[__XL$),.+#"3#55=6,?93Z)K^__^!PWJ'``"#
M[!R)5"0$A<!T9HG!BX,0`0``,?:)S8L0A=)T5(I%`(3`=`<\/70#1>OR*<V)
MUXLWA?9T/(E4)`Q055&)3"045NBZ^?__@\00BTPD"(M4)`R%P'47@#PN/741
MBT0D!"G7C70N`<'_`HDXZP6#QP3KOH/$'(GP6UY?7<.#[!QEBPT4````B4PD
M##')C50D".A;____BTPD#&4S#10```!T!>C7(0``@\0<P^AV$P``@<+%A@``
M5E.)PX/L%&6A%````(E$)`PQP(NR$`$``(U4)`B)V.@6____A<!T%XL&BU0D
M"(T$D(M0!(D0A=)TWX/`!.ORBT0D#&4S!10```!T!>AW(0``@\046U[#55=6
M4^A__?__@<-?A@``@^PLB00DB50D!&6A%````(E$)!PQP(`Z/74$_T0D!(/-
M_S'V_(M\)`2)\(GIC50D&/*N]]&-0?^)1"0(BP0DZ)#^__^)PH7`="^)Z8G'
MB?#RKHG-]]5-.VPD"`^"J@```#'`BWPD!(H,!X@,`D"$R77Q,<#I#@$``(N#
M$`$``#'VBQ"#/+(`=`-&Z_>#NXP1````C3RU"````'0@45%74NA`]___BY,0
M`0``@\00B0*%P'5#@\C_Z<L```")5"0,@^P,5\>#C!$```$```#H\O?__X/$
M$(G%A<!TV%"-1_A0BU0D%%)5Z.GW__^+@Q`!``"#Q!")*(N#$`$``(L`QT0X
M_`````")="08BP0DBA"$TG0(@/H]=`-`Z_*+LQ`!``"+3"08@^P,*T0D#(L6
MC3R*BTPD%(U$`0)0Z(7W__^#Q!")!X7`#X1G____BP:+5"08BP20_P0DBSPD
MB<%`BE?_B%#_@/H]=`2$TG7HQ@$],=*+="0$B@P6B`P00H3)=?'IZ_[__XM\
M)!QE,ST4````=`7HR1\``(/$+%M>7UW#55=6B<93Z,W[__^!PZV$``"![(P`
M``!EH10```")1"1\,<"%]@^$&0$``(`^``^$$`$``(/L#%;HU_7__X/$$(G%
MA<`/A/H```"-@U>A__^)1"0(C8-6H?__B40D#(/L#%7H;?;__X/$$(7`#X2^
M````@\`3B00D4E+_="00_W0D#.@]]O__@\00A<!TT%!0_W0D%/]T)`SH)_;_
M_X/$$(7`=+J#RO\QP/R)T8GW@^P,\JZ+?"0,]]&)3"00B=&+5"00\JZ)R/?0
MC0P"4>A2]O___W0D$(G'C8-9H?__5E!7Z%[X__^#Q!B-1"0D4%?H$/C__X/$
M$$!T&8M$)"PE`/```#T`0```=0F)^.CO_O__ZPR#[`Q7Z/CU__^#Q!"#[`Q7
MZ,SW__^#Q!#I+O___X/L#%7H._;__XDT).B#]___@\00BT0D?&4S!10```!T
M!>AK'@``@<2,````6UY?7<-6B<93Z&[Z__^!PTZ#``"#['QEH10```")1"1T
M,<"-1"044%;HVO7__X/$$(7`=3&+5"0<@>(`\```@?H`0```=`B!^@"@``!U
M&5!0:@)6Z*_T__^#Q!"%P`^4P`^VP.L",<"+3"1L93,-%````'0%Z.L=``"#
MQ'1;7L-3Z/;Y__^!P]:"``"#[!2+@P0!``#_,.@\]___C9-PWO__4HV37Z'_
M__^S(`$``%)0Z`+W__^#Q"A;PU93Z+KY__^!PYJ"``"#[!"+LP0!``#_-N@`
M]___B00DZ*#___]8_S;H\/;__UE>:@")PHV#WJ/__U!0C8-7B?__4(V#>Z'_
M_U!2Z![T__^#Q"1;7L-55U93Z&/Y__^!PT."``"![!P@``!EH10```")A"0,
M(```,<#H'_3__X/L#(V3D*'__U)0C8.4H?__4&@!$```C6PD)E7HOO/__X/$
M((U0`8'Z`1```'8"#PN%P'D$,<#K65!H`!```(VT)!,0``!65>A"]?__@\00
MB<6%P'C?@^P,C4`!4.@M]/__@\00A<!TS#GP<P>-%"@YUG*[.?!V!XT4+CG0
M<K"!_0$0``!_J/R)QXGI\Z3&!"@`BXPD#"```&4S#10```!T!>B%'```@<0<
M(```6UY?7</I(/___U575E/H@_C__X'#8X$``('LG!```(N4)+00``"+M"2P
M$```B50D$&6A%````(F$)(P0```QP(V#H*'__^@R^O__B40D#%!0:B]6Z#GT
M__^#Q!"+5"00A<!T$HGRC8.IH?__Z)WZ___I+P$``/PQP(/)_XGWC:NVH?__
M\J[WT8U!_XE$)!!04%52Z$KU__^#Q!")PHV#5Z'__XE$)!2-@[BA__^)1"08
MA=)TKX`Z`'4$BU0D%(-\)`P`=!]04%*)5"0H_W0D&.BM\O__@\00BU0D'(7`
M#X2M````@\G_,<")U_*N]]%)@'P*_R]U!TG&!`H`Z_*+1"00C40(`3W_#P``
M#X]3____C8.)HO__5U=6_W0D)%)0:``0``"-O"2H````5^@`\O__@\0@0#T`
M$```=@(/"U%1C40D-%!7Z';T__^#Q!"%P'4^BT0D/"4`\```/0"```!U+E)2
M:@%7Z+7Q__^#Q!"%P'4=B?J-@ZFA___HC?G__X/L#%?HN/+__X/$$(G&ZQ10
M4%5J`.A']/__@\00B<+I#/___XN$)(P0``!E,P44````=`7HQ1H``('$G!``
M`(GP6UY?7<.+5"0$B="*"H3)=`A"@/DO=?3K\,-75E.+5"00Z*[V__^!PXY_
M``"%TG0\@#H`=#?\,<"#R?^)U_*N]]&-1`K^.<)S&H`X+W4'2.OT.<)S#HH(
MB<9(@/DO=?*)\.LM.<)U*8`Z+W4+@^P,C8-7H?__ZPF#[`R-@[BA__]0Z/KQ
M__^#Q!#K.8`X+W4%2#G"<O8IT(U(`H'Y`!```'<@0#T`$```=@(/"XVSC`$`
M`%%04E;H=?+__X/$$(GPZP(QP%M>7\-7N2(```!64^C_]?__@</??@``@^PP
M9:$4````B40D+#'`C7PD"HVS3-[___SSI(V#NJ'__^CH]___C8/#H?__Z-WW
M__^-@\NA___HTO?__XV#U*'__^C']___C8/;H?__Z+SW__^-@^NA___HL??_
M_XV#H*'__^BF]___C8/WH?__Z)OW__^-@P&B___HD/?__XV#"Z+__^B%]___
MC8.IH?__Z'KW__^-@Q6B___H0/?__X7`=`V)PHV#`:+__^C`]___C8,FHO__
MZ"3W__^)PH7`=`N-@S&A___HI/?__XV#.*+__^@(]___B<*-@Z"A__^%TG4V
MC8-(HO__Z/'V__^)PH7`=1]0C8-9HO__:@I0C40D)U#H7/#__X/$$(7`=0^-
M5"0EC8/WH?__Z%+W__^-DV2B__^-@]NA___H0??__XM$)"QE,P44````=`7H
MH!@``(/$,%M>7\-3Z*KT__^!PXI]``"#[`B#NT@!``#_=2>-@_>A___H=/;_
M_S'2A<!T$(H`/#`/E<$QTH3`#Y7"(<J)DT@!``"+@T@!``"#Q`A;PU/H8/3_
M_X'#0'T``(/L".C^\?__@^P,4.AE\/__@\00A<!T`HL`@\0(6\-55U93Z#+T
M__^!PQ)]``"#[!R+="0PC8-FHO__Z`'V__^%P'0'@#@`B<5U#8GRC8-FHO__
M@\0<ZV504%95Z,7O__^#Q!"%P'5>@\K__(G1B?>#[`SRKHGO]]&)3"08B='R
MKHM\)!B)R/?0C0P'4>@4[___B2PDB<*-@[:A__]0C8.)HO__5E!2B50D+.@6
M\?__BU0D+(V#9J+__X/$/%M>7UWI#/;__X/$'%M>7UW#5;D&````5U93Z'[S
M__^!PUY\``"![/R```!EH10```")A"3L@```,<"+K"00@0``C;PDE````,>$
M)(0`````````C8,LH?__C;,P`0``B40D?(V#5Z'__XF$)(````#\\Z6-@TBA
M___'A"20`````````(F$)(@```"-@TVA__^)A"2,````C8.@H?__Z.'T__^%
MP'0A@#@`B<9T&H/L#%#HJ_[__XDT).B*[O__B40D$.GF!```Z&K^__^-O"2(
M````B<:%P'4SBP>%P'0GZ)_T__^%P'4%@\<$Z^R`.`!T]H/L#%#H3>[__X/$
M$(G&A<!TY.L&C;-VHO__,<")]X/)_X/L#/*N]]&-1`G_4.C$[?__C9-]HO__
MB40D$(G'@\00#[8&A,!T&E%&4%*)5"005X/'`NB][___@\00BU0D!.O?C;PD
ME````(LWA?9T*8GPZ!OT__^)QH7`="*`.`!T'>BM]___A<!T%(/L#%;HP^W_
M_X/$$(G&C7PD?.LT@\<$Z\:+%X72="V`.@!T*(G0B50D!.AZ]___BU0D!(7`
M=`Z#[`Q2Z(SM__^#Q!")QH/'!(7V=,TQP(/)_XGW@^P,\JZ+?"0,B<J#R?_R
MKO?2B<CWT(V\`@($``!7Z/;L__^)1"046(V#@J+__UK_="0(4(V#N*'__XE$
M)!A0C8.'HO__5E#_="0@Z.GN__^#Q!AHP`$``/]T)!#H>.[__X/$$$!U,.A=
M[O__BP"#^!%T)(/L#%"-@Y"B____="04_W4`4(N#\````/\PZ,?M__^#Q"#K
M/%96C40D)%#_="00Z++L__^)1"0<@\00@WPD#`!T*HV#RZ+___]T)`3_=0!0
MBX/P````_S#HB>W__X/$$,<$)`````#I`@,``(M$)"PE`/```#T`0```=<:+
M="0TZ('N__\YQG6YBT0D+"7_`0``/<`!``!UJ8/L#%?H!.S__XE$)!"-@W&B
M___HD/+__X/$$(7`=06+=0#K'8/L#%#H0.S__UI94/]U`.C]]___@\00B<:%
MP'3>B?>#R?\QP/*N]]&->?^#_P-V7%!0C8,>H___4(U$#OM0Z$;K__^#Q!"%
MP'5"@_\$=`>`?#[[+W4VBVT$A>UT+S'`@\G_B>_RKO?1C4'_@_@#=AQ04(V#
M(Z/__U"-1`W[4.@&Z___@\00A<!U`HGNZ%S[__^)Q87`#X5F`0``4%!J`%;H
MM.O__X/$$(G&A<`/A$\!``!J`FK_:NY0Z*OJ__^#Q`QJ!HV\)/0```!75NB8
M[/__@\00@+PD[`````!U78"\).T```!#=5.`O"3N````075)@+PD[P```$-U
M/X"\)/````!(=36`O"3Q````174K:@)J_VK&5NA-ZO__@\0,:BE75NA![/__
MC8/>H___7EU05_]T)!CIJ@```&H`:@!J`%;H(NK__^C"$```B<>#Q!!1:`"`
M``"-E"3T````4HE4)!16Z`#L__^#Q!"+5"0(A<!^"U%04E?HXQ```.O/@^P,
M5NC!Z___6%I7C;0DNP```%;HQQ$``(/$$(V3?:+__U`/M@0N4(U$+0!%4HV\
M),\```")5"04`?A0Z$GL__^#Q!"#_12+5"0(==6-@]ZC___&A"3K`````%55
M4(V#N*'__U=0C8,HH____W0D&%#_="0<Z!#L__^#Q"#IB````(V39*+__XV#
M]Z'__^@#\?__C;O>H___Z%SI__]65HVS1:/__U=0C8,WH____W0D&/]T)!A0
M_W0D'.C*Z___@\0@4E)HP`$``/]T)`SH5^O__X/$$$!U,>@\Z___@S@1=2?_
M1"0,Z`[I__]15_]T)!10_W0D&/]T)!A6_W0D'.B%Z___@\0@Z[F#[`S_="00
MZ"3K__^+5"00C8.@H?__Z''P__]8_W0D#.BT^?__@\00BX0D[(```&4S!10`
M``!T!>C`$0``BP0D@<3\@```6UY?7<-55U93Z,#M__^!PZ!V``"#["B+LP0!
M``#_-N@&Z___7?\VB<?H_.K__XI79(A098V#VZ'__^AV[___@\00A<!T"X`X
M,74&@'@!`'0%Z&SW__^#[`S_-NC*ZO__C9-6H___:@MJ`5)0Z$GI__^#Q""%
MP'4M@^P,_S;HJ.K__XV36Z/__VH#:@%24.@GZ?__@\0@B<>%P`^%S````.D+
M`0``BT`,OP$```"+:!B-1_^)1"0(BP8YNY01``!^'8/L#%#H8.K__VH`_W0D
M'%50Z!/H__^#Q""%P'44BX.4$0``2#M$)`AUC;\!````ZU2+$(M"""4`!"``
M/0`$``!U!8M"#.L@B50D#(/L#/\VZ!3J__]J`FH`BU0D)%)0Z#7J__^#Q"!1
M45"+@Y`1``#_-+CH@>?__X/$$(7`=9Y'Z6K___^+!CF[E!$```^.)/___X/L
M#$=0Z,SI__]96E50Z+/F__^#Q!#KVHM`#(/L#(LH_S;HK^G__X/$#(V37:/_
M_U)54.A.Z/__BT<,@\00BSCV1PI`=!:#[`S_-NB&Z?__75I74.A-Y___@\00
M@^P,_S;H<.G__XV3>Z/__VH#:@%24.COY___@\0@B<6%P'1GC8.IH?__Z-;M
M__^)QX7`=`6+10SK-^AS\O__A<")QXM%#'0A@^P,BRC_-N@FZ?__@\0,5U50
MZ,OG__^)/"3HT^C__^L?BY.0$0``BSJ+*(/L#/\VZ/WH__^#Q`Q755#HHN?_
M_X/$$(/L#/\VZ.7H__^#Q`R-DV*C__]J`5)0Z//E__]:_S:)Q^C)Z/__@\0,
MC9-WH___4E=0Z&CG__]9_S;HL.C__\9`90"-@Z"A___H+.W__X/$$(F#F!$`
M`(7`=2:#[`S_LY`1``#HGO?__X/$$(F#F!$``(7`=0N#[`R-@WVC___K-U!0
M:,`!``#_LY@1``#H#.C__X/$$(U0`8/Z`78@@_@1=!M0BX.0$0``_[.8$0``
M_S"-@YZC__]0Z)'E__^#Q!Q;7E]=PU=64XMT)!#HP>K__X'#H7,``(/L#%;H
M^//__XD$).C;\___@\00B<?H\/7__X7`="F%]G0E@#X`="!04(V#@J+__U!7
MZ%#F__^#Q!`YQW4*6XGP7E_IF^[__UM>7\.+%"3#53'25U93@>Q\`0``B40D
M"&6A%````(F$)&P!```QP(M$)`B+3)`<C40D+`_)B0R00H/Z$'7IC8PD+`$`
M`(M0-#-0((/`!#-0!#-0_-'"B5`\.<AUZ(M$)`B+`(E$)!"+1"0(BU0D$(M`
M!,'*`HE$)!B+1"0(BTPD&(M`",')`HE$)`R+1"0(BWPD#(ML)`R+0`PQSR-\
M)!`S?"0,B40D%(M$)`B+0!")1"0<BT0D+(M<)!R-M`.9>8):BT0D$(M<)!3!
MP`4!\(MT)`PS="04(W0D&#-T)!0!QHM$)#"-A`.9>8):B<L!QXGP,=/!P`4A
M\\'.`@''BT0D-#'+C80%F7F"6HML)#@!PXGXP<`%C8PIF7F"6HML)#P!PXG0
M,?`A^,'/`C'0C90JF7F"6HML)$`!R(G9P<$%`<B)\3'Y(=DQ\8VT+IEY@EJ+
M;"1$`=&)PL'"!<'+`@'1B?HQVB'"P<@",?J-O"^9>8):BVPD2`'RB<[!Q@4!
M\HG&B=@Q\"'(,=B-G"N9>8):BVPD3`'XB=?!QP4!^(G/B?'!SP(Q^2'1,?&-
MM"Z9>8):BVPD4`'9B</!PP4!V8G3B?K!RP(QVB'"P<@",?J-O"^9>8):BVPD
M5`'RB<[!Q@4!\HG&B=@Q\"'(,=B-G"N9>8):BVPD6`'XB=?!QP4!^(G/B?'!
MSP(Q^2'1,?&-M"Z9>8):BVPD7`'9B</!PP4!V8G3B?K!RP(QVB'"P<@",?J-
MO"^9>8):BVPD8`'RB<[!Q@4!\HG&B=@Q\"'(,=B-G"N9>8):BVPD9`'XB=?!
MQP4!^(G/B?'!SP(Q^2'1,?&-M"Z9>8):`=F)P\'#!0'9B=.)^L'+`C':(<+!
MR`(Q^HG%B=@!\HG.,>C!Q@4AR,')`@'RBW0D:#'8C;0WF7F"6HGO`?")UC'/
MP<8%(=?!R@(!\(MT)&PQ[XV<,YEY@EJ)S@'?B<,QUL'#!2'&P<@"`=^+7"1P
M,<Z-G!V9>8):BVPD=`'>B?O!PP6-C"F9>8):BVPD>`'>B=,QPR'[,=/!SP*-
ME"J9>8):`<N)\<'!!0'+B<$Q^2'QP<X",<$!T8G:P<(%`=&+5"1\C800H>O9
M;HGZ,?(QVL'+`@'"B<C!P`4!PHN$)(````"-O`>AZ]ENB?`QV#'(`?B)U\''
M!0'XB<^+C"2$````P<\"C;0.H>O9;HG9,?DQT0'QB<;!Q@4!\8G6BY0DB```
M`,'.`HV<$Z'KV6Z)^C'R,<(!VHG+P<@"P<,%`=J)PXN$)(P```"-O`>AZ]EN
MB?`QV#'(`?B)U\''!0'XB<^+C"20````P<\"C;0.H>O9;HG9,?DQT0'QB<;!
MQ@4!\8G6BY0DE````,'.`HV<$Z'KV6Z)^C'R,<+!R`(!VHG+P<,%`=J)PXN$
M))@```"-O`>AZ]ENB?`QV#'(`?B)U\''!0'XB<^+C"2<````P<\"C;0.H>O9
M;HG9,?DQT0'QB<;!Q@4!\8G6BY0DH````,'.`HV<$Z'KV6Z)^C'R,<+!R`(!
MVHG+P<,%`=J)PXN$)*0```"-O`>AZ]ENB?`QV#'(`?B)U\''!0'XB<^+C"2H
M````P<\"C;0.H>O9;HG9,?DQT0'QB<;!Q@4!\8G6BY0DK````,'.`HV<$Z'K
MV6Z)^C'R,<+!R`(!VHG+P<,%`=J)PXN$)+````"-O`>AZ]ENB?`QV#'(`?B)
MU\''!0'XB<^+C"2T````P<\"C;0.H>O9;HG9,?DQT0'QB<;!Q@4!\8G6BY0D
MN````,'.`HV<$Z'KV6Z)^C'R,<+!R`(!VHG+P<,%`=J)PXN$)+P```"-O`>A
MZ]ENB?`QV#'(`?B)U\''!0'XB<^+C"3`````P<\"C;0.H>O9;HG9,?DQT0'Q
MB<;!Q@4!\8G6BY0DQ````,'.`HV<$Z'KV6Z)^C'R,<+!R`*)Q0':BX0DR```
M`(G+P<,%`=J-G`>AZ]ENB?`QZ#'(`=B)T\')`L'#!0'8B>L)RXG?B>LAUR'+
MP<H""?N+O"3,````C;0^W+P;CXG/`?.)Q@G7P<8%`?.)_HG/(<8AU\'(`@GW
MB[0DT````(VT-=R\&X\!]XG>P<8%`?>)U@G&(=[!RP*)]8G6(<8)[HNL)-0`
M``"-C"G<O!N/B=V)PP'.">N)^2'[P<$%`<Z)V8G#(>L)RXN,)-@```"-E`K<
MO!N/B>D!T\'/`HGR"?G!P@4A\0'3P<X"B<J)Z2'Y"=&+E"3<````C800W+P;
MCXGZ`<&)V`GRP<`%`<&)T(GZ(=@A\L'+`@G"BX0DX````(V$!=R\&X\!PHG(
MP<`%`<*)\`G8(<B)Q8GP(=@)Z(NL).0```"-O"_<O!N/`?B)U\''!0'XB<^)
MV<'/`@GY(=&)S8G9(?D)Z8NL).@```"-M"[<O!N/`?&)QL'&!0'QB=:)^L'.
M`@GR(<+!R`*)U8GZ(?()ZHNL).P```"-G"O<O!N/`=J)R\'#!0':B<.)\`G8
M(<B)Q8GP(=@)Z(NL)/````"-O"_<O!N/`?B)U\''!0'XB<^)V<'/`@GY(=&)
MS8G9(?D)Z8NL)/0```"-M"[<O!N/`?&)QL'&!0'QB=:)^L'.`@GR(<*)U8GZ
M(?()ZHNL)/@```"-G"O<O!N/`=J)R\'(`L'#!0':B<.)\`G8(<B)Q8GP(=@)
MZ(NL)/P```"-O"_<O!N/`?B)U\''!0'XB<^)V<'/`@GY(=&)S8G9(?D)Z8NL
M)``!``"-M"[<O!N/`?&)QL'&!0'QB=:)^L'.`@GR(<+!R`*)U8GZ(?()ZHNL
M)`0!``"-G"O<O!N/B<6)\`':">B)RR'(P<,%`=J)PXGP(>@)V(N<)`@!``"-
MG!_<O!N/`=B)T\')`L'#!0'8B>L)RXG?B>LAUR'+P<H""?N+O"0,`0``C;0^
MW+P;CP'SB<;!Q@4!\XG."=:)]XG.(<<AUL'(`@G^B[PD$`$``(V\/=R\&X\!
M_HG?P<<%`?Z)UPG'(=_!RP*)_8G7(<<)[XNL)!0!``"-C"G<O!N/`?F)]\''
M!0'YB<<)WR'WB?V)QR'?">^+K"08`0``C90JW+P;CP'7B<K!S@+!P@4!UXN4
M)!P!``"-E!#6P6+*B=@Q\#'(P<D"`=")^L'"!0'0BY0D(`$``(V<$];!8LJ)
M\C'*,?K!SP(!VHG#P<,%`=J+G"0D`0``C;0>UL%BRHG+,?LQP\'(`@'SB=;!
MQ@4!\XG&BX0D*`$``(V,`=;!8LJ)^#'P,=`!R(G9P<$%`<B)T8N4)"P!``#!
MR0*-E!?6P6+*B?<QSS'?`=>)PL'"!0'7BY0D,`$``,'+`HVT%M;!8LJ)RC':
M,<+!R`(!\HG^P<8%`?*)QHN$)#0!``"-A`'6P6+*B=DQ\3'YP<\"`<&)T,'`
M!0'!BX0D.`$``(V<`];!8LJ)\#'X,=`!V(G+P<,%`=B)TXN4)#P!``"+;"00
MP<L"C906UL%BRHG^,=XQSL')`@'6B<+!P@4!UHN4)$`!``"-O!?6P6+*B=HQ
MRC'"P<@"`?J)]\''!0'ZB<>+A"1$`0``C80#UL%BRHG+,?LQ\\'.`@'#B=#!
MP`4!PXN$)$@!``"-C`'6P6+*B?@Q\#'0`<B)V<'!!0'(B=&+E"1,`0``P<D"
MC907UL%BRHGW,<\QW\'+`@'7B<+!P@4!UXN4)%`!``"-M!;6P6+*B<HQVC'"
MP<@"`?*)_L'&!0'RB<:+A"14`0``C80!UL%BRHG9,?$Q^<'/`@'!B=#!P`4!
MP8N$)%@!``"-G`/6P6+*B?`Q^#'0`=B)R\'#!0'8B=.+E"1<`0``P<L"C906
MUL%BRHG^,=XQSL')`@'6B<+!P@4!UHN4)&`!``"-O!?6P6+*B=HQRC'"P<@"
M`?J)]\''!0'ZB[PD9`$``(V\.];!8LJ)RS'#,?/!S@(!^XG7P<<%`?N+O"1H
M`0``C;P]UL%BR@'/B<$Q\0-T)!0QT<'*`@-4)`P!^8G?`UPD&,''!0'YBWPD
M"`-$)!R)#XE?!(E7"(EW#(E'$(N$)&P!``!E,P44````=`7H@P(``('$?`$`
M`%M>7UW#4^B)WO__@<-I9P``@^P4:F#HQ=G__\<``2-%9\=`!(FKS>_'0`C^
MW+J8QT`,=E0R$,=`$/#ATL/'0!0`````QT`8`````,=`7`````"#Q!A;PU57
M5E.#[!R+;"0XBUPD,(MT)#2-!.T``````T,4<P/_0QB)0Q2+>UR)Z,'H'0%#
M&(U#'(E$)`B%_W1)N4````")Z"GY.<U^`HG(C5,<`?HY\G,*C0P".<YS`_P/
M"XT\!HE\)`PY\G8$.?IR[OR)UXG!*<7SI(M+7`'!B4M<@_E`=77K)_R#_3]^
M/SMT)`AW*(U&0#MT)`B)1"0,<B2+?"0(N1````"#[4#SI8G8Z"#S__^+="0,
MZ\V-0UPYQG/1ZYHY1"0(<];KDCMT)`AV"HM$)`@!Z#G&<H([="0(<PV-!"XY
M1"0(#X)O____BWPD"(GI\Z2):UR#Q!Q;7E]=P^B,WO__!1EF``!55U93@^P<
MBUPD-(MT)#")1"0$BT,4BU,8B<7!Z`,/RHE4)`B#X#^-4QP/S8UX`8E4)`S&
M1`,<@`'Z@_\X?BFY0````"GY_#'`B=?SJHG8C7L<B4PD#.AN\O__BT0D#+D.
M````\ZOK#KDX````*?G\,<")U_.JBT0D"(EK6(E#5(G8Z$+R__^+`X/L#,'H
M&(@&BP/!Z!"(1@&+`XAF`HL#B$8##[9#!XA&!`^W0P:(1@6+0P2(9@:+0P2(
M1@</MD,+B$8(#[=#"HA&"8M#"(AF"HM#"(A&"P^V0P^(1@P/MT,.B$8-BT,,
MB&8.BT,,B$8/#[9#$XA&$`^W0Q*(1A&+0Q"(9A*+0Q"(1A-3BUPD%.@[V?__
M@\0L6UY?7<-3Z!'<__^!P_%D``"#[`CHG]G__X/$"%O#Z$S=__\%V60``%6)
MY5-2C9@@____BP.#^/]T!__0@^L$Z_)86UW#@^P,Z$W<__^#Q`S#````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"]T;7``4$%27U1-4$1)4@!414U01$E2`%1-4`!54T52`%5315).04U%
M`"XN`"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA
M;',Z.E!!4CHZ0D]/5`!E>&4`+W!R;V,O)6DO)7,`4$%27U1%35``4$%27U!2
M3T=.04U%`#H`+P!015),-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)3P!0
M05)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$14)5
M1P!005)?0T%#2$4`4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)
M4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]
M`#$`3$1?3$E"4D%265]0051(`%-94U1%30`E,#)X`'!A<BT`)7,E<R5S)7,`
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`H97)R;F\])6DI"@`E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@
M=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A
M=&EO;BD*`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S
M`"5S)7-T96UP+25U+25U)7,`05)'5@`8`'!E<FP`4$%2.CI086-K97(Z.E9%
M4E-)3TX`,2XP-3``56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S
M(&9A:6QE9"`H97)R;F\])6DI"@`M90`M+0!E=F%L("=E>&5C("]U<W(O8FEN
M+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U
M;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!
M1TE#+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I
M9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D
M=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*
M;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE
M.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI
M;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A
M<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&
M:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL
M93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M
M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ
M.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G
M"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E
M<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N
M86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M
M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L
M;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG
M<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF
M:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H
M*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*)%!!4E]-04=)
M0R`](")<;E!!4BYP;5QN(CL*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@
M)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T
M:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E
M>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@
M/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I
M;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E
M=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL
M;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@
M)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@
M)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q
M,#(T.PIM>2`D;6%G:6-?<&]S.PII9B`H)'-I>F4@/#T@)&-H=6YK7W-I>F4I
M('L*)&UA9VEC7W!O<R`](#`["GT@96QS:68@*"AM>2`D;2`]("1S:7IE("4@
M)&-H=6YK7W-I>F4I(#X@,"D@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D;3L*
M?2!E;'-E('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&-H=6YK7W-I>F4["GT*
M=VAI;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K*%]&2"P@)&UA9VEC7W!O
M<RP@,"D["G)E860H7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D
M4$%27TU!1TE#*2D["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-
M04=)0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S=#L*?0HD;6%G
M:6-?<&]S("T]("1C:'5N:U]S:7IE.PI]"FQA<W0@:68@)&UA9VEC7W!O<R`\
M(#`["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"P@,#L*<F5A9"!?1D@L("1B
M=68L(#0["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"`M('5N<&%C:R@B3B(L
M("1B=68I+"`P.PHD9&%T85]P;W,@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?
M;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@
M(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@
M=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H
M<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]
M("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U
M;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ
M+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L
M("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A
M;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N
M86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*
M?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN
M960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL
M92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@
M)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA
M;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2![
M"F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L
M"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@
M>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO
M9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2!D96QE=&4@)')E<75I<F5?
M;&ES='LD;6]D=6QE?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO
M861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@
M9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D
M9F@@)&EN9F\M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@[
M"GT*96QS92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&EN9F\M/GMC
M<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@)&9I
M;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*8FEN
M;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F
M86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q
M=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL
M92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP
M72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@
M+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E
M<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S
M("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U
M9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@
M-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R
M9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*
M9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%
M(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S
M("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP
M72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M
M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U
M;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII
M9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`
M05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L
M<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*
M=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S
M5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D
M7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@
M)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L
M("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF
M("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@
M97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G
M*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L
M;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@
M)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*
M?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@
M>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER
M92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!
M4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET
M.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T
M*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6
M*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@
M)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I
M;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R
M8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D
M9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B
M4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H
M)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG
M*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N
M*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL
M;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G
M/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE
M("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+
M7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I
M;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI
M(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A
M7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM
M>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I
M<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0IF;W)E86-H(&UY("1K97D@*'-O
M<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0[
M"B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G
M:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@
M/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD
M;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q
M*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I
M.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A
M=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H
M*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T10
M04XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,["B1F:6QE
M<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V
M86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB
M7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@)69I;&5S
M*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I
M('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*
M)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>
M0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0[
M"GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF
M("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH
M)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*96QS:68@*"UF
M("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q
M*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@
M;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N
M9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*
M<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F
M:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI
M('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["F]P96X@1DE,
M12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*
M8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E($9)3$4[
M"E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M
M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N
M86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H
M0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D[
M"GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B
M1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@
M.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ
M6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP
M<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT
M*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@
M:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L
M(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D
M;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P
M96XH;7D@)&9H+"`B/"(L("1O=70I.PIB:6YM;V1E*"1F:"D["B1C='@M/F%D
M9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-A8VAE7VYA;64@/2`D8W1X+3YH
M97AD:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T
M:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^
M<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M
M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!
M1TE#*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I[
M"FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M
M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI:
M:7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/
M.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE
M("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I
M.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*07)C:&EV93HZ6FEP.CIS971#:'5N
M:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*
M)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D
M14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%
M3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@
M>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D
M;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI
M<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA
M;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O
M"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#
M;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?
M;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL
M92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S
M=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I
M*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@
M86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U
M=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M
M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I
M.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]
M"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID
M:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R
M(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R
M86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%2
M1U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U
M:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X
M="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG
M*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P
M871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R
M;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I
M<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC
M=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A
M<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E
M($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E
M8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@
M24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S
M<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T
M.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I
M<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T
M=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER
M92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A
M;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R
M97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U
M:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@
M<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D
M<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!4
M14U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2![
M"FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M
M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U
M:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I
M;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R
M.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R
M;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T52
M3D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@
M/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L
M:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP
M9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE
M(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N
M("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M
M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L
M("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O
M+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U
M9CL*?0IE;'-E('L*;7D@)&1I9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S
M=#HZ4TA!.PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM
M>2`D9F@L("(\(BP@)'!R;V=N86UE*3L*8FEN;6]D92@D9F@I.PHD8W1X+3YA
M9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE>&1I9V5S=#L*?2!\
M?"`D;71I;64["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TD
M9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!
M3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"([
M"GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-
M4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F
M:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D
M9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L
M;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@
M;7D@)&9H+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T
M96UP;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT
M<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN
M960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL
M:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E
M=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A
M;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@
M/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@
M86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*
M)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/
M1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^
M/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T
M=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X
M97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*
M?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]
M7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%
M35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D
M0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@
M+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5]
M(CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\
M/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ
M9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'
M971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D
M*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<
M12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM0
M05)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD
M14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@
M5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@
M)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.
M($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM
M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@
M("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#
M3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.
M?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG
M=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@
M/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@
M:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B([
M"GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E
M<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#
M;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@
M<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI
M8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@
M0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I
M.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O
M9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M
M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@
M*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI]
M.PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@
M*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ
M7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@```%]?14Y67U!!
M4E]#3$5!3E]?("`@("`@("`@("`@("`@`````'!E<FQX<VDN8P````$;`SOP
M````'0```-"2__\,`0``8);__S`!``!XEO__``P``/^9__]$`0``BYK__Y`!
M``"ZFO__J`$``!R;___4`0``S)S__T0"```MGO__#`,``*B>__]8`P``XY[_
M_X@#```XG___U`,``!.@__]0!```&*#__V0$``#5H?__3`4``.JA__]@!0``
MF*+__ZP%``#TH___\`4``#ZD__\0!@``::3__SP&```8I?__O`8``-NJ__\H
M"@``UZW__ZP+```UKO__2`P``#FN__]<#```%;K__YP,``!GNO__P`P``&:[
M___\#```C;S__T`-```4``````````%Z4@`!?`@!&PP$!(@!```@````'```
M`+R1__^0`P````X(1@X,2@\+=`1X`#\:.RHR)"(0````0````"B5__\8````
M`````$@```!4````LYC__XP`````00X(A0)!#@R'`T$.$(8$0PX4@P5.#C!W
M#C1!#CA!#CQ%#D!(#C!K#A1#PPX00<8.#$''#@A!Q0X$```4````H````/.8
M__\O`````$,.(&L.!``H````N`````J9__]B`````$P."(8"00X,@P-%#B`"
M30X,0<,."$'&#@0``&P```#D````0)G__[`!````00X(A0)!#@R'`T$.$(8$
M00X4@P5.#D`"F@Y$00Y(00Y,00Y03@Y`50Y,00Y04@Y`1PY$1`Y(10Y,00Y0
M3@Y`=`Y,4@Y02`Y``ED.%$'##A!!Q@X,0<<."$'%#@0```#$````5`$``(":
M__]A`0```$$."(4"00X,AP-!#A"&!$,.%(,%40Z@`6`.K`%!#K`!2`Z@`6$.
MK`%!#K`!2`Z@`4\.I`%!#J@!1`ZL`40.L`%(#J`!10ZD`4$.J`%$#JP!1`ZP
M`4@.H`%1#JP!7`ZP`4D.M`%)#K@!00Z\`4$.P`%(#J@!10ZL`4$.L`%(#J`!
M7PZL`4$.L`%(#J`!0PZL`4$.L`%(#J`!2`ZL`4$.L`%0#J`!6`X40<,.$$'&
M#@Q!QPX(0<4.!$@````<`@``&9O__WL`````00X(A@)##@R#`TX.B`%1#HP!
M00Z0`4@.@`%?#H0!00Z(`4(.C`%!#I`!2`Z``6$.#$'##@A!Q@X$```L````
M:`(``$B;__\[`````$$."(,"3@X<2`X@3`XD3`XH00XL00XP2`X(0<,.!`!(
M````F`(``%.;__]5`````$$."(8"00X,@P-.#AQ(#B!.#AQ"#B!&#AQ!#AA"
M#AQ)#B!!#B1'#BA'#BQ!#C!(#@Q!PPX(0<8.!```>````.0"``!<F___VP``
M``!!#@B%`D$.#(<#00X0A@1!#A2#!5$.L$!7#KQ`1P[`0$$.Q$!'#LA`10[,
M0$4.T$!(#K!`5@ZT0$4.N$!(#KQ`00[`0$@.L$!)#KQ`1`[`0$@.L$`"2`X4
M0<,.$$'&#@Q!QPX(0<4.!````!````!@`P``NYO__P4`````````Y````'0#
M``"LF___O0$```!!#@B%`D$.#(<#00X0A@1!#A2#!5$.L"%Q#K0A00ZX(4(.
MO"%!#L`A2`ZP(70.M"%!#K@A00Z\(4$.P"%(#K`A:PZT(4$.N"%!#KPA2`[`
M(4@.L"$"0`ZT(4$.N"%!#KPA1`[`(4$.Q"%!#L@A10[,(4@.T"%(#K`A2PZT
M(4$.N"%%#KPA00[`(4@.L"%5#K0A00ZX(4(.O"%!#L`A2`ZP(50.O"%!#L`A
M2`ZP(44.M"%!#K@A00Z\(4(.P"%(#K`A8@X40\,.$$'&#@Q!QPX(0<4.!```
M`!````!<!```@9S__Q4`````````2````'`$``""G/__K@````!!#@B'`D$.
M#(8#00X0@P0"4@H.'$@+0PX<1PX@2`X0:@X400X800X<00X@2`X01\,.#$'&
M#@A!QPX$`$````"\!```Y)S__UP!````00X(AP)&#@R&`T$.$(,$3@Y``O,.
M1$@.2$$.3$4.4$@.0'D.$$'##@Q!Q@X(0<<.!```'``````%``#\G?__2@``
M``!!#@B#`DX.$'D."$'##@0H````(`4``":>__\K`````$$."(,"3@X02`X<
M00X@2`X020X(0<,.!````'P```!,!0``)9[__Z\`````00X(A0)!#@R'`T$.
M$(8$00X4@P5.#C!E"@X40@M!#C1!#CA!#CQ!#D!(#C!/#CQ:#D!1#D1'#DA!
M#DQ!#E!6#A1!PPX00<8.#$''#@A!Q0X$10XP@P6%`H8$AP-##A1!PPX00<8.
M#$''#@A!Q0X$:`,``,P%``!4GO__PP4```!!#@B%`D8.#(<#00X0A@1!#A2#
M!5$.D(("`H8*#IR"`D$.H(("5@MN#IR"`D$.H(("2`Z0@@)8#IR"`DD.H(("
M5`Z0@@)(#I2"`D(.F(("00Z<@@)%#J""`DL.D(("<0Z<@@)!#J""`D@.D(("
M;@Z<@@)!#J""`D@.D(("4PZ<@@);#J""`DH.G(("1PZ8@@)$#IR"`D$.H(("
M2PZD@@)'#JB"`D$.K(("1`ZP@@)(#IB"`D4.G(("1`Z@@@)(#I""`E(.G(("
M00Z@@@)*#J2"`D,.J(("00ZL@@)(#K""`D@.D(("0PZ4@@)!#IB"`D4.G(("
M1`Z@@@),#I""`E$.E(("0PZ8@@)!#IR"`D@.H(("2`Z0@@)\#IR"`D$.H(("
M5PZ0@@),#IR"`D$.H(("1@Z<@@)!#IB"`D$.G(("0PZ@@@)(#I""`EH.E(("
M00Z8@@)'#IR"`D4.H(("2`Z0@@)K#I2"`D$.F(("1PZ<@@)%#J""`D@.D(("
M5@H.E(("00Z8@@)"#IR"`D$.H(("2`Z0@@),#I2"`D(.F(("0@Z<@@)!#J""
M`D@.E(("0@Z8@@)(#IR"`D$.H(("2`Z0@@)^#I2"`D(.F(("0@Z<@@)!#J""
M`D@.E(("0@Z8@@)!#IR"`D$.H(("3`Z<@@)!#IB"`D$.G(("00Z@@@)$#J2"
M`D4+0@Z4@@)"#IB"`D(.G(("00Z@@@)/#I""`D$.E(("10Z8@@)(#IR"`D4.
MH(("2`Z0@@))#I2"`D$.F(("00Z<@@)!#J""`D<.D(("0PZ<@@)!#J""`D8.
MG(("00Z8@@)!#IR"`D@.H(("2`Z0@@)'#I2"`D4.F(("1@Z<@@).#J""`D@.
MD(("6`Z4@@)!#IB"`D$.G(("1PZ@@@)!#J2"`DH.J(("00ZL@@)$#K""`D@.
MD(("8@Z4@@)!#IB"`D<.G(("00Z@@@)*#J2"`D0.J(("00ZL@@)$#K""`D@.
MD(("00Z4@@)!#IB"`D4.G(("1`Z@@@)(#I""`E<.E(("00Z8@@)$#IR"`D$.
MH(("1`ZD@@)$#JB"`D$.K(("1`ZP@@)(#I""`D4.G(("1`Z@@@)5#IR"`D0.
MH(("2`Z0@@)>#A1!PPX00<8.#$''#@A!Q0X$````@`$``#@)``"KH/___`(`
M``!!#@B%`D$.#(<#00X0A@1!#A2#!4X./$@.0$8./$(.0%L.,%<./$(.0$T.
M1$(.2$$.3$$.4$@.,$<./$(.0$T.1$(.2$$.3$$.4$@.,&X./$$.0$<.1$0.
M2$$.3$$.4$@.,'4./$(.0$<.1$(.2$4.3$$.4$@.,$$.-$$..$$./$D.0$@.
M,%L./$(.0$8./$$..$$./$$.0$@.,$@./$0.0$@.-$<..$$./$$.0$L.,$L.
M/$(.0$8./$$..$$./$$.0$@.,$,./$(.0$T.1$(.2$$.3$$.4$@.,&T*#CQ$
M#D!(#C1!#CA!#CQ!#D!/"TT./$(.0$@.-$$..$$./$$.0$@.,$,*#CQ"#D!(
M#C1(#CA!#CQ!#D!&#CQ"#D!*#C1'#CA!#CQ!#D!&#CQ"#D!7#C!-#CQ&#D!(
M#C!-#CQ("T$.-$$..$4./$8.0$@.,$X.-$P..$(./$<.0$4.,$,.%$'##A!!
MQ@X,0<<."$'%#@0``%````"\"@``(Z+__UX`````00X(AP)!#@R&`T$.$(,$
M4@X<00X@4`X050X400X81PX<00X@2`X010K##@Q#Q@X(0<<.!$4+0<,.#$'&
M#@A!QPX$`$0````0"P``<(K__]H!````1`P!`$H0!0)U`$00!P)U?!`&`G5X
M0Q`#`G5T3`\#=7`&`[$!P0P!`$'#0<9!QT'%0PP$!````!````!8"P``Y:'_
M_P0`````````/````&P+``#5H?__W`L```!!#@B%`D,.#(<#00X0A@1!#A2#
M!48.D`,#RPL.%$'##A!!Q@X,0<<."$'%#@0``"````"L"P``<:W__U(`````
M00X(@P).#AQ"#B!_#@A!PPX$`#@```#0"P``GZW___\`````00X(A0)!#@R'
M`T$.$(8$00X4@P5##C`"\PX40<,.$$'&#@Q!QPX(0<4.!$`````,#```8J[_
M_R<!````2PX(A0)!#@R'`T$.$(8$00X4@P5##C`"A0X\`H`.0$P.%$'##A!!
MQ@X,0<<."$'%#@0`'````%`,``!%K___&0````!!#@B#`DX.$$@."$'##@0`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````/____\`````_____P`````!````
M`0````$```"\`@``#P```$\$```,`````!````T````=.@``]?[_;XP!```%
M````A`@```8```!D`@``"@```&T$```+````$````!4``````````P```-2>
M```"````P`$``!0````1````%P```*P-```1````]`P``!(```"X````$P``
M``@````8`````````/O__V\!```(^O__;PH`````````````````````````
M````````````````````````````````!)X`````````````-A```$80``!6
M$```9A```'80``"&$```EA```*80``"V$```QA```-80``#F$```]A````81
M```6$0``)A$``#81``!&$0``5A$``&81``!V$0``AA$``)81``"F$0``MA$`
M`,81``#6$0``YA$``/81```&$@``%A(``"82```V$@``1A(``%82``!F$@``
M=A(``(82``"6$@``IA(``+82``#&$@``UA(``.82``#V$@``!A,``!83```F
M$P``-A,``$83``!6$P``9A,``'83``"&$P``EA,``*83``#($P``````````
M```=.@`````````0````````````````````````````````````````````
M`````````````*````5````%00``$$```!=!```80````````/____^Y0@``
M1T-#.B`H06QP:6YE(#DN,BXP*2`Y+C(N,```+G-H<W1R=&%B`"YI;G1E<G``
M+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N<F5L+F1Y;@`N<F5L+G!L=``N
M:6YI=``N<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H
M9'(`+F5H7V9R86UE`"YC=&]R<P`N9'1O<G,`+F1Y;F%M:6,`+F1A=&$`+F)S
M<P`N8V]M;65N=```````````````````````````````````````````````
M``````````L````!`````@```'0!``!T`0``%P```````````````0``````
M```3````]O__;P(```",`0``C`$``-@````#``````````0````$````'0``
M``L````"````9`(``&0"```@!@``!`````$````$````$````"4````#````
M`@```(0(``"$"```;00``````````````0`````````M````"0````(```#T
M#```]`P``+@````#``````````0````(````-@````D```!"````K`T``*P-
M``#``0```P```!(````$````"````#\````!````!@`````0````$```$0``
M`````````````0`````````Z`````0````8````@$```(!```)`#````````
M`````!`````$````10````$````&````L!,``+`3```8```````````````(
M````"````$X````!````!@```,@3``#($P``528``````````````0``````
M``!4`````0````8````=.@``'3H```P```````````````$`````````6@``
M``$````"`````$````!```!./0`````````````$`````````&(````!````
M`@```%!]``!0?0``]```````````````!`````````!P`````0````(```!$
M?@``1'X``'`,``````````````0`````````>@````$````#````])T``/2-
M```(```````````````$`````````($````!`````P```/R=``#\C0``"```
M````````````!`````````"(````!@````,````$G@``!(X``-`````$````
M``````0````(````20````$````#````U)X``-2.```L`0`````````````$
M````!````)$````!`````P````"@````D```)```````````````!```````
M``"7````"`````,```!`H```))```#00`````````````"``````````G```
M``$````P`````````"20```:```````````````!`````0````$````#````
@```````````^D```I0```````````````0``````````
